import pandas as pd


def sepal(product, upstream):
    """Compute sepal area
    """
    data = pd.read_csv(upstream['get'])
    ft = data['sepal length (cm)'] * data['sepal width (cm)']
    df = pd.DataFrame({'sepal area (cm2)': ft})
    df.to_csv(product, index=False)


def petal(product, upstream):
    """Compute petal area
    """
    data = pd.read_csv(upstream['get'])
    ft = data['petal length (cm)'] * data['petal width (cm)']
    df = pd.DataFrame({'petal area (cm2)': ft})
    df.to_csv(product, index=False)


def features(product, upstream):
    """Join raw data with generated features
    """
    first = pd.read_csv(upstream['get'])
    sepal = pd.read_csv(upstream['sepal'])
    petal = pd.read_csv(upstream['petal'])
    df = first.join(sepal).join(petal)
    df = df[sorted(df.columns)]
    df.to_csv(product, index=False)



# Notebook to train a model

# +
import pickle

import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.metrics import classification_report
from sklearn.ensemble import RandomForestClassifier

# + tags=["parameters"]
upstream = ['features']
product = None
# -

df = pd.read_csv(str(upstream['features']))
X = df.drop('target', axis='columns')
y = df.target

X_train, X_test, y_train, y_test = train_test_split(X,
                                                    y,
                                                    test_size=0.33,
                                                    random_state=42)

# + tags=["model-training"]
clf = RandomForestClassifier(n_estimators=5)
clf.fit(X_train, y_train)
# -

y_pred = clf.predict(X_test)

print(classification_report(y_test, y_pred))

with open(product['model'], 'wb') as f:
    pickle.dump(clf, f)



import versioneer

from glob import glob
from os.path import basename
from os.path import splitext

from setuptools import find_packages
from setuptools import setup

setup(
    name='package_name',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    py_modules=[splitext(basename(path))[0] for path in glob('src/*.py')],
    include_package_data=True,
)
